## `citros data`

This section contain all data related functionality

### list
Will list all recorded batches under `.citros/data` folder

### service 
This section controls citros data service that that exposes data/report using REST API

### DB
We use postgres DB to cash batch data for fast quering. This section cintrols citros DB functionality. 
